=========
Changelog
=========

----------------
0.1 - 2011-10-20
----------------

* Provide the core functionality of OAuth into Zope/Plone, through the
  use of custom forms and the Pluggable Authentication System.
* Contain just the basic storage for all associated data types, but
  extensibility is allowed.
